@@ -12,10 +12,6 @@
 #ifndef MONITOR_LABEL_H
 #define MONITOR_LABEL_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
